@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2015-2022 MinIO, Inc.
+// Copyright (c) 2015-2024 MinIO, Inc.
 //
 // This file is part of MinIO Object Storage stack
 //
@@ -117,6 +117,7 @@ type SiteReplicationInfo struct {
 	Name                    string     `json:"name,omitempty"`
 	Sites                   []PeerInfo `json:"sites,omitempty"`
 	ServiceAccountAccessKey string     `json:"serviceAccountAccessKey,omitempty"`
+	APIVersion              string     `json:"apiVersion,omitempty"`
 }
 
 // SiteReplicationInfo - returns cluster replication information.
@@ -167,6 +168,7 @@ type PeerInfo struct {
 	SyncState          SyncStatus      `json:"sync"`             // whether to enable| disable synchronous replication
 	DefaultBandwidth   BucketBandwidth `json:"defaultbandwidth"` // bandwidth limit per bucket in bytes/sec
 	ReplicateILMExpiry bool            `json:"replicate-ilm-expiry"`
+	APIVersion         string          `json:"apiVersion,omitempty"`
 }
 
 // BucketBandwidth has default bandwidth limit per bucket in bytes/sec
@@ -279,6 +281,7 @@ const (
 	SRIAMItemSvcAcc        = "service-account"
 	SRIAMItemSTSAcc        = "sts-account"
 	SRIAMItemIAMUser       = "iam-user"
+	SRIAMItemExternalUser  = "external-user"
 )
 
 // SRSvcAccCreate - create operation
@@ -293,6 +296,7 @@ type SRSvcAccCreate struct {
 	Name          string                 `json:"name"`
 	Description   string                 `json:"description"`
 	Expiration    *time.Time             `json:"expiration,omitempty"`
+	APIVersion    string                 `json:"apiVersion,omitempty"`
 }
 
 // SRSvcAccUpdate - update operation
@@ -304,18 +308,21 @@ type SRSvcAccUpdate struct {
 	Description   string          `json:"description"`
 	SessionPolicy json.RawMessage `json:"sessionPolicy"`
 	Expiration    *time.Time      `json:"expiration,omitempty"`
+	APIVersion    string          `json:"apiVersion,omitempty"`
 }
 
 // SRSvcAccDelete - delete operation
 type SRSvcAccDelete struct {
-	AccessKey string `json:"accessKey"`
+	AccessKey  string `json:"accessKey"`
+	APIVersion string `json:"apiVersion,omitempty"`
 }
 
 // SRSvcAccChange - sum-type to represent an svc account change.
 type SRSvcAccChange struct {
-	Create *SRSvcAccCreate `json:"crSvcAccCreate"`
-	Update *SRSvcAccUpdate `json:"crSvcAccUpdate"`
-	Delete *SRSvcAccDelete `json:"crSvcAccDelete"`
+	Create     *SRSvcAccCreate `json:"crSvcAccCreate"`
+	Update     *SRSvcAccUpdate `json:"crSvcAccUpdate"`
+	Delete     *SRSvcAccDelete `json:"crSvcAccDelete"`
+	APIVersion string          `json:"apiVersion,omitempty"`
 }
 
 // SRPolicyMapping - represents mapping of a policy to a user or group.
@@ -326,6 +333,7 @@ type SRPolicyMapping struct {
 	Policy      string    `json:"policy"`
 	CreatedAt   time.Time `json:"createdAt,omitempty"`
 	UpdatedAt   time.Time `json:"updatedAt,omitempty"`
+	APIVersion  string    `json:"apiVersion,omitempty"`
 }
 
 // SRSTSCredential - represents an STS credential to be replicated.
@@ -335,6 +343,28 @@ type SRSTSCredential struct {
 	SessionToken        string `json:"sessionToken"`
 	ParentUser          string `json:"parentUser"`
 	ParentPolicyMapping string `json:"parentPolicyMapping,omitempty"`
+	APIVersion          string `json:"apiVersion,omitempty"`
+}
+
+// OpenIDUserAccessInfo contains information to access and refresh the token
+// that is used to access to UserInfo OpenID endpoint.
+type OpenIDUserAccessInfo struct {
+	RefreshToken string `json:"refreshToken,omitempty"`
+	AccessToken  string `json:"accessToken,omitempty"`
+}
+
+// OpenIDUser holds information to maintain an virtual user in OpenID
+type OpenIDUser struct {
+	AccessInfo OpenIDUserAccessInfo `json:"accessInfo,omitempty"`
+}
+
+// SRExternalUser - represents an external user information to be replicated.
+type SRExternalUser struct {
+	APIVersion  string `json:"apiVersion,omitempty"`
+	Name        string `json:"name"`
+	IsDeleteReq bool   `json:"isDeleteReq"`
+
+	OpenIDUser *OpenIDUser `json:"openIDUser,omitempty"`
 }
 
 // SRIAMUser - represents a regular (IAM) user to be replicated. A nil UserReq
@@ -343,11 +373,13 @@ type SRIAMUser struct {
 	AccessKey   string              `json:"accessKey"`
 	IsDeleteReq bool                `json:"isDeleteReq"`
 	UserReq     *AddOrUpdateUserReq `json:"userReq"`
+	APIVersion  string              `json:"apiVersion,omitempty"`
 }
 
 // SRGroupInfo - represents a regular (IAM) user to be replicated.
 type SRGroupInfo struct {
-	UpdateReq GroupAddRemove `json:"updateReq"`
+	UpdateReq  GroupAddRemove `json:"updateReq"`
+	APIVersion string         `json:"apiVersion,omitempty"`
 }
 
 // SRCredInfo - represents a credential change (create/update/delete) to be
@@ -363,6 +395,7 @@ type SRCredInfo struct {
 
 	// This is the JSON encoded value of github.com/minio/minio/cmd.UserIdentity
 	UserIdentityJSON json.RawMessage `json:"userIdentityJSON"`
+	APIVersion       string          `json:"apiVersion,omitempty"`
 }
 
 // SRIAMItem - represents an IAM object that will be copied to a peer.
@@ -391,8 +424,12 @@ type SRIAMItem struct {
 	// Used when Type = SRIAMItemIAMUser
 	IAMUser *SRIAMUser `json:"iamUser"`
 
+	// Used when Type = SRIAMItemExternalUser
+	ExternalUser *SRExternalUser `json:"externalUser"`
+
 	// UpdatedAt - timestamp of last update
-	UpdatedAt time.Time `json:"updatedAt,omitempty"`
+	UpdatedAt  time.Time `json:"updatedAt,omitempty"`
+	APIVersion string    `json:"apiVersion,omitempty"`
 }
 
 // SRPeerReplicateIAMItem - copies an IAM object to a peer cluster.
@@ -472,7 +509,8 @@ type SRBucketMeta struct {
 	ExpiryUpdatedAt time.Time `json:"expiryUpdatedAt,omitempty"`
 
 	// Cors is base64 XML representation of CORS config
-	Cors *string `json:"cors,omitempty"`
+	Cors       *string `json:"cors,omitempty"`
+	APIVersion string  `json:"apiVersion,omitempty"`
 }
 
 // SRPeerReplicateBucketMeta - copies a bucket metadata change to a peer cluster.
@@ -548,6 +586,7 @@ type SRBucketInfo struct {
 	DeletedAt                  time.Time `json:"bucketDeletedTimestamp,omitempty"`
 	CorsConfigUpdatedAt        time.Time `json:"corsTimestamp,omitempty"`
 	Location                   string    `json:"location,omitempty"`
+	APIVersion                 string    `json:"apiVersion,omitempty"`
 }
 
 // OpenIDProviderSettings contains info on a particular OIDC based provider.
@@ -626,15 +665,17 @@ func (adm *AdminClient) SRPeerGetIDPSettings(ctx context.Context) (info IDPSetti
 
 // SRIAMPolicy - represents an IAM policy.
 type SRIAMPolicy struct {
-	Policy    json.RawMessage `json:"policy"`
-	UpdatedAt time.Time       `json:"updatedAt,omitempty"`
+	Policy     json.RawMessage `json:"policy"`
+	UpdatedAt  time.Time       `json:"updatedAt,omitempty"`
+	APIVersion string          `json:"apiVersion,omitempty"`
 }
 
 // ILMExpiryRule - represents an ILM expiry rule
 type ILMExpiryRule struct {
-	ILMRule   string    `json:"ilm-rule"`
-	Bucket    string    `json:"bucket"`
-	UpdatedAt time.Time `json:"updatedAt,omitempty"`
+	ILMRule    string    `json:"ilm-rule"`
+	Bucket     string    `json:"bucket"`
+	UpdatedAt  time.Time `json:"updatedAt,omitempty"`
+	APIVersion string    `json:"apiVersion,omitempty"`
 }
 
 // SRInfo gets replication metadata for a site
@@ -651,6 +692,7 @@ type SRInfo struct {
 	ReplicationCfg map[string]replication.Config // map of bucket -> replication config
 	ILMExpiryRules map[string]ILMExpiryRule      // map of ILM Expiry rule to content
 	State          SRStateInfo                   // peer state
+	APIVersion     string                        `json:"apiVersion,omitempty"`
 }
 
 // SRMetaInfo - returns replication metadata info for a site.
@@ -704,6 +746,7 @@ type SRStatusInfo struct {
 	// ILMExpiryStats map of ILM Expiry rules to slice of deployment IDs with stats. This is populated if there
 	// are mismatches or if a specific ILM expiry rule's stats are requested
 	ILMExpiryStats map[string]map[string]SRILMExpiryStatsSummary
+	APIVersion     string `json:"apiVersion,omitempty"`
 }
 
 // SRPolicyStatsSummary has status of policy replication misses
@@ -711,6 +754,7 @@ type SRPolicyStatsSummary struct {
 	DeploymentID   string
 	PolicyMismatch bool
 	HasPolicy      bool
+	APIVersion     string
 }
 
 // SRUserStatsSummary has status of user replication misses
@@ -720,6 +764,7 @@ type SRUserStatsSummary struct {
 	UserInfoMismatch bool
 	HasUser          bool
 	HasPolicyMapping bool
+	APIVersion       string
 }
 
 // SRGroupStatsSummary has status of group replication misses
@@ -729,6 +774,7 @@ type SRGroupStatsSummary struct {
 	HasGroup          bool
 	GroupDescMismatch bool
 	HasPolicyMapping  bool
+	APIVersion        string
 }
 
 // SRBucketStatsSummary has status of bucket metadata replication misses
@@ -751,6 +797,7 @@ type SRBucketStatsSummary struct {
 	HasReplicationCfg        bool
 	HasQuotaCfgSet           bool
 	HasCorsCfgSet            bool
+	APIVersion               string
 }
 
 // SRILMExpiryStatsSummary has status of ILM Expiry rules metadata replication misses
@@ -758,6 +805,7 @@ type SRILMExpiryStatsSummary struct {
 	DeploymentID          string
 	ILMExpiryRuleMismatch bool
 	HasILMExpiryRules     bool
+	APIVersion            string
 }
 
 // SRSiteSummary holds the count of replicated items in site replication
@@ -791,6 +839,7 @@ type SRSiteSummary struct {
 	TotalGroupPolicyMappingCount int // total number of group policy mappings seen on this site
 	TotalILMExpiryRulesCount     int // total number of ILM expiry rules seen on the site
 	TotalCorsConfigCount         int // total number of CORS config seen on the site
+	APIVersion                   string
 }
 
 // SREntityType specifies type of entity
@@ -828,6 +877,7 @@ type SRStatusOptions struct {
 	Entity         SREntityType
 	EntityValue    string
 	ShowDeleted    bool
+	APIVersion     string
 }
 
 // IsEntitySet returns true if entity option is set
@@ -1085,8 +1135,9 @@ func (adm *AdminClient) SRPeerRemove(ctx context.Context, removeReq SRRemoveReq)
 
 // ReplicateRemoveStatus - returns status of unlink request.
 type ReplicateRemoveStatus struct {
-	Status    string `json:"status"`
-	ErrDetail string `json:"errorDetail,omitempty"`
+	Status     string `json:"status"`
+	ErrDetail  string `json:"errorDetail,omitempty"`
+	APIVersion string `json:"apiVersion,omitempty"`
 }
 
 // SRRemoveReq - arg body for SRRemoveReq
@@ -1104,9 +1155,10 @@ type SRStateEditReq struct {
 
 // SRStateInfo - site replication state information
 type SRStateInfo struct {
-	Name      string              `json:"name"`
-	Peers     map[string]PeerInfo `json:"peers"`
-	UpdatedAt time.Time           `json:"updatedAt"`
+	Name       string              `json:"name"`
+	Peers      map[string]PeerInfo `json:"peers"`
+	UpdatedAt  time.Time           `json:"updatedAt"`
+	APIVersion string              `json:"apiVersion,omitempty"`
 }
 
 const (
