@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2015-2022 MinIO, Inc.
+// Copyright (c) 2015-2024 MinIO, Inc.
 //
 // This file is part of MinIO Object Storage stack
 //
@@ -28,6 +28,10 @@ import (
 	"time"
 )
 
+//msgp:clearomitted
+//msgp:tag json
+//go:generate msgp
+
 // BackendType - represents different backend types.
 type BackendType int
 
@@ -369,6 +373,8 @@ type Logger map[string]Status
 // TargetIDStatus containsid and status
 type TargetIDStatus map[string]Status
 
+//msgp:replace backendType with:string
+
 // backendType - indicates the type of backend storage
 type backendType string
 
@@ -409,13 +415,33 @@ type ServerProperties struct {
 	CommitID       string            `json:"commitID,omitempty"`
 	Network        map[string]string `json:"network,omitempty"`
 	Disks          []Disk            `json:"drives,omitempty"`
-	PoolNumber     int               `json:"poolNumber,omitempty"`
+	PoolNumber     int               `json:"poolNumber,omitempty"` // Only set if len(PoolNumbers) == 1
+	PoolNumbers    []int             `json:"poolNumbers,omitempty"`
 	MemStats       MemStats          `json:"mem_stats"`
 	GoMaxProcs     int               `json:"go_max_procs,omitempty"`
 	NumCPU         int               `json:"num_cpu,omitempty"`
 	RuntimeVersion string            `json:"runtime_version,omitempty"`
 	GCStats        *GCStats          `json:"gc_stats,omitempty"`
 	MinioEnvVars   map[string]string `json:"minio_env_vars,omitempty"`
+	Edition        string            `json:"edition"`
+}
+
+// MemStats is strip down version of runtime.MemStats containing memory stats of MinIO server.
+type MemStats struct {
+	Alloc      uint64
+	TotalAlloc uint64
+	Mallocs    uint64
+	Frees      uint64
+	HeapAlloc  uint64
+}
+
+// GCStats collect information about recent garbage collections.
+type GCStats struct {
+	LastGC     time.Time       `json:"last_gc"`     // time of last collection
+	NumGC      int64           `json:"num_gc"`      // number of garbage collections
+	PauseTotal time.Duration   `json:"pause_total"` // total pause for all collections
+	Pause      []time.Duration `json:"pause"`       // pause history, most recent first
+	PauseEnd   []time.Time     `json:"pause_end"`   // pause end times history, most recent first
 }
 
 // DiskMetrics has the information about XL Storage APIs
@@ -447,6 +473,17 @@ type DiskMetrics struct {
 	APILatencies map[string]interface{} `json:"apiLatencies,omitempty"`
 }
 
+// CacheStats drive cache stats
+type CacheStats struct {
+	Capacity   int64 `json:"capacity"`
+	Used       int64 `json:"used"`
+	Hits       int64 `json:"hits"`
+	Misses     int64 `json:"misses"`
+	DelHits    int64 `json:"delHits"`
+	DelMisses  int64 `json:"delMisses"`
+	Collisions int64 `json:"collisions"`
+}
+
 // Disk holds Disk information
 type Disk struct {
 	Endpoint        string       `json:"endpoint,omitempty"`
@@ -471,6 +508,8 @@ type Disk struct {
 	HealInfo        *HealingDisk `json:"heal_info,omitempty"`
 	UsedInodes      uint64       `json:"used_inodes"`
 	FreeInodes      uint64       `json:"free_inodes,omitempty"`
+	Local           bool         `json:"local,omitempty"`
+	Cache           *CacheStats  `json:"cacheStats,omitempty"`
 
 	// Indexes, will be -1 until assigned a set.
 	PoolIndex int `json:"pool_index"`
