@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2015-2022 MinIO, Inc.
+// Copyright (c) 2015-2024 MinIO, Inc.
 //
 // This file is part of MinIO Object Storage stack
 //
@@ -169,7 +169,7 @@ func (adm *AdminClient) RemoveCannedPolicy(ctx context.Context, policyName strin
 
 // AddCannedPolicy - adds a policy for a canned.
 func (adm *AdminClient) AddCannedPolicy(ctx context.Context, policyName string, policy []byte) error {
-	if policy == nil {
+	if len(policy) == 0 {
 		return ErrInvalidArgument("policy input cannot be empty")
 	}
 
