@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2015-2022 MinIO, Inc.
+// Copyright (c) 2015-2024 MinIO, Inc.
 //
 // This file is part of MinIO Object Storage stack
 //
@@ -22,6 +22,7 @@ package madmin
 import (
 	"math/bits"
 	"net/http"
+	"strings"
 	"time"
 )
 
@@ -61,6 +62,8 @@ const (
 	TraceFTP
 	// TraceILM will trace events during MinIO ILM operations
 	TraceILM
+	// TraceKMS are traces for interactions with KMS.
+	TraceKMS
 	// Add more here...
 
 	// TraceAll contains all valid trace modes.
@@ -73,6 +76,23 @@ const (
 	TraceBatch = TraceBatchReplication | TraceBatchKeyRotation | TraceBatchExpire // |TraceBatch<NextFeature>
 )
 
+// FindTraceType will find a single trace type from a string,
+// as returned by String(). Matching is not case sensitive.
+// Will return 0 if not found.
+func FindTraceType(s string) TraceType {
+	bitIdx := uint(0)
+	for {
+		idx := TraceType(1 << bitIdx)
+		if idx > TraceAll {
+			return 0
+		}
+		if strings.EqualFold(idx.String(), s) {
+			return idx
+		}
+		bitIdx++
+	}
+}
+
 // Contains returns whether all flags in other is present in t.
 func (t TraceType) Contains(other TraceType) bool {
 	return t&other == other
