@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2015-2022 MinIO, Inc.
+// Copyright (c) 2015-2024 MinIO, Inc.
 //
 // This file is part of MinIO Object Storage stack
 //
@@ -25,10 +25,15 @@ import (
 	"net/http"
 	"net/url"
 	"strings"
+	"time"
 
 	"github.com/minio/minio-go/v7/pkg/s3utils"
 )
 
+//msgp:clearomitted
+//msgp:tag json
+//go:generate msgp
+
 // AdminAPIVersion - admin api version used in the request.
 const (
 	AdminAPIVersion   = "v3"
@@ -119,3 +124,63 @@ func closeResponse(resp *http.Response) {
 		resp.Body.Close()
 	}
 }
+
+// TimedAction contains a number of actions and their accumulated duration in nanoseconds.
+type TimedAction struct {
+	Count   uint64 `json:"count"`
+	AccTime uint64 `json:"acc_time_ns"`
+	MinTime uint64 `json:"min_ns,omitempty"`
+	MaxTime uint64 `json:"max_ns,omitempty"`
+	Bytes   uint64 `json:"bytes,omitempty"`
+}
+
+// Avg returns the average time spent on the action.
+func (t TimedAction) Avg() time.Duration {
+	if t.Count == 0 {
+		return 0
+	}
+	return time.Duration(t.AccTime / t.Count)
+}
+
+// AvgBytes returns the average time spent on the action.
+func (t TimedAction) AvgBytes() uint64 {
+	if t.Count == 0 {
+		return 0
+	}
+	return t.Bytes / t.Count
+}
+
+// Merge other into t.
+func (t *TimedAction) Merge(other TimedAction) {
+	t.Count += other.Count
+	t.AccTime += other.AccTime
+	t.Bytes += other.Bytes
+	if t.Count == 0 {
+		t.MinTime = other.MinTime
+	}
+	if other.Count > 0 {
+		t.MinTime = min(t.MinTime, other.MinTime)
+	}
+	t.MaxTime = max(t.MaxTime, other.MaxTime)
+}
+
+// NodeCommon - Common fields across most node-specific health structs
+type NodeCommon struct {
+	Addr  string `json:"addr"`
+	Error string `json:"error,omitempty"`
+}
+
+// GetAddr - return the address of the node
+func (n *NodeCommon) GetAddr() string {
+	return n.Addr
+}
+
+// SetAddr - set the address of the node
+func (n *NodeCommon) SetAddr(addr string) {
+	n.Addr = addr
+}
+
+// SetError - set the address of the node
+func (n *NodeCommon) SetError(err string) {
+	n.Error = err
+}
